@@ -8,7 +8,10 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.Type;
+import org.gnu.javagnome.Handle;
+
 /**
  *
  */
@@ -22,7 +25,7 @@ public class CanvasBpath extends CanvasShape {
 	 * Constructs an instance of CanvasBpath from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasBpath(int handle) {
+	CanvasBpath(Handle handle) {
 		super(handle);
 	}
 
@@ -33,11 +36,7 @@ public class CanvasBpath extends CanvasShape {
 		return new Type(gnome_canvas_bpath_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_bpath_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
