@@ -8,12 +8,13 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Boxed;
+
+import org.gnu.javagnome.Struct;
 
 /**
  * Class that can be used to play a sound.
  */
-public class Sound extends Boxed 
+public class Sound extends Struct 
 {
 	
 	/**
